@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::Util::EmulatePhase::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::Util::EmulatePhase::VERSION = '0.01025802';
+  $Dist::Zilla::Util::EmulatePhase::VERSION = '0.01025803';
 }
 
 #ABSTRACT: Nasty tools for probing L<< C<Dist::Zilla>'s|Dist::Zilla >> internal state.
@@ -20,6 +20,7 @@ use Sub::Exporter -setup => {
 };
 
 
+
 sub deduplicate {
   my ( @args, %seen, @out ) = @_;
   @args->each(
@@ -53,6 +54,7 @@ sub get_plugins {
   my $zilla = $config->{zilla};
 
   if ( not $zilla->isa('Dist::Zilla') ) {
+
     #require Carp;
     #Carp::cluck('get_plugins({ zilla => $something}) is not Dist::Zilla, might be a bug');
   }
@@ -61,7 +63,8 @@ sub get_plugins {
 
   if ( $zilla->can('plugins') ) {
     $plugins = $zilla->plugins();
-  } else {
+  }
+  else {
     return;
   }
 
@@ -169,15 +172,18 @@ sub get_prereqs {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Util::EmulatePhase - Nasty tools for probing L<< C<Dist::Zilla>'s|Dist::Zilla >> internal state.
 
 =head1 VERSION
 
-version 0.01025802
+version 0.01025803
 
 =head1 METHODS
 
@@ -243,16 +249,25 @@ Extended usage:
      isa  => [qw( =AutoPrereqs )],
    });
 
+=begin MetaPOD::JSON v1.1.0
+
+{
+    "namespace":"Dist::Zilla::Util::EmulatePhase",
+    "interface":"exporter"
+}
+
+
+=end MetaPOD::JSON
+
 =head1 AUTHOR
 
 Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2013 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
